@@ -183,7 +183,7 @@ void gok_keyboard_notify_xkb_event (XkbEvent* event);
 gboolean gok_keyboard_layout (GokKeyboard* pKeyboard, KeyboardLayouts layout, KeyboardShape shape, gboolean force);
 gboolean gok_keyboard_branch_byKey (GokKeyboard *keyboard, GokKey* pKey);
 gboolean gok_keyboard_branch_gui (AccessibleNode* pNodeAccessible, GokSpySearchType type);
-gboolean gok_keyboard_branch_gui_actions (GokKeyboard *keyboard, AccessibleNode* pNodeAccessible);
+gboolean gok_keyboard_branch_gui_actions (GokKeyboard *keyboard, AccessibleNode* pNodeAccessible, gint action_ndx);
 gboolean gok_keyboard_branch_edittext (void);
 gboolean gok_chunker_chunk (GokKeyboard* pKeyboard);
 gboolean gok_chunker_chunk_rows_ttb (GokKeyboard* pKeyboard, gint ChunkOrder);
