@@ -1051,7 +1051,9 @@ gboolean gok_spy_check_queues(void)
 			break;
 		case GOKSPY_STATE_EVENT:
 			gok_log("GOKSPY_STATE_EVENT");
-			((AccessibleChangeListenerCB)(m_ptheStateChangeListener))(en->event->source);
+			if (m_ptheStateChangeListener) {
+				((AccessibleChangeListenerCB)(m_ptheStateChangeListener))(en->event->source);
+			}
 			break;
 		case GOKSPY_WINDOW_ACTIVATE_EVENT:
 			gok_log("GOKSPY_WINDOW_ACTIVATE_EVENT");
@@ -1061,7 +1063,9 @@ gboolean gok_spy_check_queues(void)
 				gok_spy_accessible_unref (m_ptheWindowAccessible);
 				m_ptheWindowAccessible = en->event->source;
 				gok_spy_accessible_ref (m_ptheWindowAccessible);
-				((AccessibleChangeListenerCB)(m_ptheWindowChangeListener))(m_ptheWindowAccessible);
+				if (m_ptheWindowChangeListener) {
+					((AccessibleChangeListenerCB)(m_ptheWindowChangeListener))(m_ptheWindowAccessible);
+				}
 			}
 			break;
 		case GOKSPY_DEFUNCT_EVENT:
@@ -1072,7 +1076,9 @@ gboolean gok_spy_check_queues(void)
 			gok_spy_accessible_unref (m_ptheAccessibleWithText);
 			m_ptheWindowAccessible = NULL;
 			m_ptheAccessibleWithText = NULL;
-			((AccessibleChangeListenerCB)(m_ptheWindowChangeListener))(m_ptheWindowAccessible);
+			if (m_ptheWindowChangeListener) {
+				((AccessibleChangeListenerCB)(m_ptheWindowChangeListener))(m_ptheWindowAccessible);
+			}
 			break;
 		case GOKSPY_CONTAINER_EVENT:
 			gok_log("GOKSPY_CONTAINER_EVENT");
@@ -2265,7 +2271,7 @@ gok_spy_get_toolbar_item (Accessible *toolbar_child)
 }
 
 static GokSpyUIFlags 
-gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboard_ui_flags)
+gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboard_ui_flags, AccessibleNodeFlags context_flags)
 {
 	Accessible* child;
 	Accessible* parent;
@@ -2285,21 +2291,28 @@ gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboar
 		gok_log ("not worth searching.");
 		gok_log_leave ();
 		return ui_flags;
-	}	
+	}			
 	parent_role = Accessible_getRole (parent);
 	child_count = Accessible_getChildCount (parent);
+	
+	/* assign context */
+	if (parent_role == SPI_ROLE_HTML_CONTAINER) {
+			context_flags.data.inside_html_container = TRUE;
+	}
+	
 	/* MAX_CHILD_COUNT is a bit of a kludge and will cause certain table items to be unreachable via UI Grab */
 	if (child_count > MAX_CHILD_COUNT)
 		child_count = MAX_CHILD_COUNT;
 	for (i = 0; i < child_count; ++i)
 	{
-		AccessibleNodeFlags flags;
+		AccessibleNodeFlags flags;  /* TODO? memcpy context_flags? */
 		flags.value = 0;
+		flags.data.inside_html_container = context_flags.data.inside_html_container;
+
 		child = Accessible_getChildAtIndex (parent, i);
 		if (child)
 		{
 			gok_spy_accessible_implicit_ref (child);
-			flags.value = 0;
 			role = Accessible_getRole (child);
 			if (keyboard_ui_flags.data.menus && gok_spy_is_menu_role (role))
 			{
@@ -2325,7 +2338,7 @@ gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboar
 				}
 				else
 				{
-				    ui_flags.value |= gok_spy_search_component_list (child, keyboard_ui_flags).value;
+				    ui_flags.value |= gok_spy_search_component_list (child, keyboard_ui_flags, context_flags).value;
 				}
 			}
 			if ((keyboard_ui_flags.data.gui || keyboard_ui_flags.data.editable_text) && 
@@ -2342,18 +2355,21 @@ gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboar
 			}
 			if (!flags.data.is_toolbar_item) /* toolbar items already added */
 			{
-				if (flags.value) 
+			        AccessibleNodeFlags non_context_flags = flags;
+				non_context_flags.data.inside_html_container = FALSE;
+
+				if (non_context_flags.value) 
 				{
 				    _priv_ui_nodes = gok_spy_append_node (_priv_ui_nodes, child, flags);
 				    /* special case for notebook tabs, whose children should also appear */
   				    if (role == SPI_ROLE_PAGE_TAB)
   				    {
-  					ui_flags.value |= gok_spy_search_component_list (child, keyboard_ui_flags).value;
+  					ui_flags.value |= gok_spy_search_component_list (child, keyboard_ui_flags, context_flags).value;
   				    }
 				}
 				else
 				{
-					ui_flags.value |= gok_spy_search_component_list (child, keyboard_ui_flags).value;
+					ui_flags.value |= gok_spy_search_component_list (child, keyboard_ui_flags, context_flags).value;
 				}
 			}
 			gok_spy_accessible_unref (child);
@@ -2387,12 +2403,15 @@ GokSpyUIFlags
 gok_spy_update_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboard_ui_flags)
 {
 	GokSpyUIFlags ui_flags;
+	AccessibleNodeFlags context_flags;
 
 	gok_log_enter ();
 
 	gok_spy_free_nodes (_priv_ui_nodes);
 	_priv_ui_nodes = NULL;
-	ui_flags = gok_spy_search_component_list (rootAccessible, keyboard_ui_flags);
+
+	context_flags.value = 0;
+	ui_flags = gok_spy_search_component_list (rootAccessible, keyboard_ui_flags, context_flags);
 	/* _priv_ui_nodes is now re-assigned, by above call. */
 	gok_spy_resolve_namesakes (_priv_ui_nodes);
 
@@ -2474,4 +2493,3 @@ gboolean gok_spy_accessible_is_desktopChild(Accessible* accessible)
 	gok_log_leave();
 }
 */
-
